function [cp,dH]=cpdh_t(t)
%Give termodynamic data for R-1801-mixture at temperature T.
%Mixture dependence is neglected, calculate at "standard mixture"
% cpa, cpb, cpc, cpd ordnade enl:
%        c2h2, c2h4,  c2h6,    h2,   ch4,  c3h8,  c3h6, c3h4pd, c3h4ma
ynorm = [.0051, .3151, .0462, .1940, .3116, .0324, .0913,  .0015,  .00195];

%Cp-data (from Properties of Gases and Liquids)
cpa= [6.406, 0.909, 1.292, 6.483, 4.598, -1.009, 0.886,2.366, 3.513];
cpb= [1.810E-2, 3.740E-2, 4.254E-2, 2.215E-3, 1.245E-2,7.315E-2, 5.602E-2, 4.723E-2, 4.453E-2];
cpc= [-1.196E-5, -1.994E-5, -1.657E-5, -3.298E-6, 2.860E-6,-3.789E-5, -2.771E-5, -2.822E-5, -2.803E-5];
cpd= [3.373E-9, 4.192E-9, 2.081E-9, 1.826E-9, -2.703E-9,7.678E-9, 5.266E-9, 6.645E-9, 7.701E-9];

% Calculation of cp for the mixture in J/(mol*K)
cpi=4.1868*(cpa+cpb.*t+cpc.*t^2+cpd.*t^3);

cp=sum(cpi.*ynorm);

% Calculation of the reaction enthalpies in J/mol
dh0=[-1.7458e5,-1.3704e5,-1.6513e5];         %reaction enthalpies at 298 K
icp=cpa.*(t-298)+cpb.*(t^2-298^2)/2+cpc.*(t^3-298^3)/3+cpd.*(t^4-298^4)/4;
icp=icp*4.1868;
                                                 
dH(1)=dh0(1)+icp(2)-icp(1)-icp(4);		% C2H2 + H2 --> C2H4
dH(2)=dh0(2)+icp(3)-icp(2)-icp(4);		% C2H4 + H2 --> C2H6
dH(3)=dh0(3)+icp(7)-icp(9)-icp(4);		% C3H4-ma + H2 --> C3H6
dH(4)=dH(3);					% C3H4-pd + H2 --> C3H6
