% Calculation of the cooalnt molar flow in mol/(m2 s)
% molar heat in J/(mol K) and heat transfer coefficient i W/(m2 K)
% [Gm,cp,hk] = gmhkyl(T)

function [Gm,cp,hk] = gmhkyl(T)
% Data
porbadd=1/3; robadd=1000; ropart=1500; depart=3.435e-3; dcyl=3.0e-3;
Lbadd=1.1; dp=1.0e5; Ptot=24.5e5; R=8.314; molm=28.0e-3; visexp=1.78e-5;

cp=31.15-1.357e-2*T+2.68e-5*T^2-1.168e-8*T^3;
lamg=3.919e-4+9.816e-5*T-5.067e-8*T^2+1.504e-11*T^3;
visko=visexp*sqrt(T/300);
rogas=Ptot*molm/T/R;

% Calculation of molar fow
k1=368*(1-porbadd)*visko/dcyl/1.24;
k2=porbadd^3*dcyl*rogas/(1-porbadd)/1.24;
G=-k1/2+sqrt(k1^2/4+k2*dp/Lbadd);
Gm=G/molm;

% Calculation of heat transfer coefficient
SV=6*robadd/ropart/depart; Re=G/SV/visko;
jh=1.076*0.57*Re^(-0.41);
Pr=cp*visko/lamg/molm;
hk=jh*cp*Gm*Pr^(-2/3);

 