% Calculation of the gas mixture heat conductivity i W/(m K) at the temperature T K
function lambdmed =lambdabe(T)
%
%Data ordered:
%      H2   CH4 C2H6 C2H4 C3H8 C3H6
molbr=[19.4 31.2 4.6 31.5 3.2 9.1];                %molar ratio
visko=[1.03 1.48 1.16 1.28 1.00 1.06]*1.0e-5;      %viscosity at T=333 K
molm=[2 16 30.1 28.1 44.1 42.1];                   %molar mass
%
%Constants in lambdas temperature dependence:
lba=[8.099 -1.869 -31.74 -17.60 1.858 -7.584]*1.0e-3;
lbb=[66.89 8.727 22.01 12.00 -.4698 6.101]*1.0e-5;
lbc=[-4.158 1.179 -1.923 .3335 2.177 .9966]*1.0e-7;
lbd=[15.62 -3.614 16.64 -1.3664 -8.409 -3.840]*1.0e-11;
%
%Calculation of lambda for each component:
lambda=lba + lbb.*T + lbc.*T^2 + lbd.*T^3;
%
%Calculation of the lambda in the mixture: 
ntot=length(molm);
for i=1:ntot
for j=1:ntot
lkvot=visko(i)/visko(j)*molm(j)/molm(i);
A=(1+lkvot^(1/2)*(molm(i)/molm(j))^(1/4))^2/(8*(1+molm(i)/molm(j)))^(1/2);
AY(j)=A*molbr(j);
end
ykorr(i)=molbr(i)/sum(AY);
end
lambdmed=sum(ykorr.*lambda);

