function b=reg_uppg(modellval,b0)

modellnamn={'ModellA','ModellB','ModellC','ModellD'};
b_ModellA={'k','K_EA','K_E'};
b_ModellB={'k','K_E'};
b_ModellC={'k','K_E'};
b_ModellD={'k','a','b'};

modell=char(modellnamn(modellval)); % name of the choosen model

r=[1.04,3.13,5.21,3.82,4.19,2.391,3.867,2.199,0.75];    % meassured reaction rate
P_E=[1,1,1,3,5,.5,.5,.5,.5];                            % partial pressure ethene
P_EA=[1,1,1,1,1,1,.5,3,5];                              % partial pressure ethane
P_H=[1,3,5,3,3,3,5,3,1];                                % partial pressure hydrogen

p_name=eval(['(b_',modell,');']);   % parameters for the chosen model
p=length(p_name);
if length(b0)~=p
    error('Starting values does not match number of parameters to fit')
end

[b,resnorm,residual,exitflag,output,lambda,jacobian]=lsqnonlin(modell,b0,[],[],[],P_E,P_EA,P_H,r); 
% the name of the model is also the name of the m-file where the reaction 
% and the residuals are calculated
J=jacobian; % p rows, n columns
[res,r_m]=eval([modell,'(b,P_E,P_EA,P_H,r)']); % the residual (res) could be direved directly with lsqnonlin (residual) 
% but reaction rate of the chosen model (r_m) with the estimated parameter values still needs to be calculated

n=length(r);                % observations
deg_f=n-p;                  % degree of freedom
SSb=sum(res.^2);            % the sum of the squared residuals
s=(SSb/deg_f).^0.5;         % standard deviation (the sum of the squared residuals / degree of freedom)^0.5
M=(J'*J)^-1;
se_b=s*diag(M).^.5;         % standard error of the parameter estimator

alfa=0.05;
konf_b=(se_b*tinv(1-alfa/2,deg_f))';

b_min=b-konf_b;
b_max=b+konf_b;

C=zeros(size(M,1));        % correlation coeffisient

for i=1:size(M,1)
    for j=1:size(M,1)
        C(i,j)=M(i,j)/(M(i,i)*M(j,j))^.5;
    end
end


% Cij=0, low correlation
% Cij=+-1, high correlation

% Residual analysis: plot the residual vs time or r_modell

% Developed from Studentisering
R=J*M*J';
studentiserad_residual=res./(s*(1-diag(R)').^.5);

figure(modellval)
plot(r_m,studentiserad_residual,'+')
title(modell)
ylabel('Studentiserad residual')
xlabel('Reaktion rate, model')

% Parameter significanse, test the null hypotesis H_0: beta(j)=0 against
% the alternative 
% H_1 beta(j)~=0
se_b=se_b';
ttest=b./se_b;

tB=tinv(1-alfa/2,deg_f);
b_sign=cell(1,length(b));
for i=1:length(b)
    if ttest(i)-tB<0
        b_sign(:,i)={[char(p_name(i)), ' is not significant']};
    else
        b_sign(:,i)={[char(p_name(i)), ' is significant']};
    end
end

% Conclusions regarding the parameter significanse could also be derived if b_min and b_max
% do have diferent signs which means that the parameter is insignificant
% since it could have the value 0


figure(modellval*10) % se figure 2-11 and 3-4 i Montgomery ed. 5
plot(sort(studentiserad_residual),(100*[1:length(studentiserad_residual)]-0.5)/length(studentiserad_residual),'o')
xlabel('Studentiserad residual')
ylabel('Normal % probability')
title(modell)

figure(modellval*100) % se figure 2-11 and 3-4 i Montgomery ed. 5
subplot(3,1,1)
plot(P_E,studentiserad_residual,'o')
xlabel('P_E [bar]')
ylabel('Studentiserad residual')
subplot(3,1,2)
plot(P_EA,studentiserad_residual,'o')
xlabel('P_E_A [bar]')
ylabel('Studentiserad residual')
subplot(3,1,3)
plot(P_H,studentiserad_residual,'o')
xlabel('P_H [bar]')
ylabel('Studentiserad residual')
suptitle(modell)

figure(modellval*1000)

plot(1:length(r),r,'o',1:length(r),r_m,'s')
ylabel('Reaktion rate')
xlabel('Case')
legend('Meassurement data','Model')
title(modell)
% Save the results which will be used for the parameter estimation  for the
% chosen model in a structured array
eval([modell,'=struct(''','b','''',',b,','''b_min','''',',b_min,'...
    ,'''b_max','''',',b_max,','''C','''',',C,','''res','''',',res,','''r_m','''',',r_m,'...
    ,'''s','''',',s,','''se_b','''',',se_b,','''tB','''',',tB,','''ttest','''',',ttest,'...
    ,'''studentiserad_residual','''',',studentiserad_residual,','''SSb','''',',SSb,'...
    ,'''konf_b','''',',konf_b);'])

eval([modell,'.b_sign=b_sign;']);
eval([modell,'.p_name=p_name']);
eval(['save(','''',modell,'resultat''',',','''',modell,'''',')'])
