function r=rhast(T,yc2h2,yc3h4ma,yco)

%  Routine used to calculate the reaction rate for R-1801 according to the model
%  developed by Bjrn Widmark and Stefan Larsson (Master thesis KRT-90)


%  IN DATA:
%  T                        temperature in K
%  yc2h2,yc3h4ma,yco        molar ratio of acetylene,methylacetylene and carbon monoxid


%  OUT DATA:
%  Reaction rate in mol/(s*kg kat):
%  r(1) for reaction  C2H2 + H2 --> C2H4
%  r(2)               C2H4 + H2 --> C2H6
%  r(3)               C3H4-ma + H2 --> C3H6
%  r(4)               C3H4-pd + H2 --> C3H6


%  DATA:
%  Rate constants at T0=343 K :
   k01=1.161e-3;
   k02=4.497e-7;
   k03=3.1654e-1*k01;
   k04=6.4889e-2*k02;

%  Adsorptions equilibrium constants:
   K1CO=3.8481;
   K2CO=7.1144;

%  Activtions energies:
   E1=4.047e4;
   E2=9.046e4;

   T0=343;              % Referens temperature
   R=8.314;             % Gas constant
   TT=(1/T0-1/T)/R;

%  Calculation of reaction rate
   r(1)=k01*exp(E1*TT)*yc2h2/(yc2h2+K1CO*yco);
   r(2)=k02*exp(E2*TT)/(yc2h2+K2CO*yco);
   r(3)=k03*exp(E1*TT)*yc3h4ma/(yc2h2+K1CO*yco);
   r(4)=k04*exp(E2*TT)/(yc2h2+K2CO*yco);



